@@ -153,7 +153,7 @@ class ModelImporter:
 
                 warnings = list(form.warnings.items())
 
-            if not instance or not instance.pk:
+            if not instance or not instance.pk or errors:
                 failed += 1
 
             result_row = importresult.append(i, row, errors, instance, to_be_created, warnings)
