@@ -1,4 +1,7 @@
+from collections import defaultdict
+
 from django import forms
+from django.core.exceptions import NON_FIELD_ERRORS
 
 from .magic import CachedChoiceFieldFormMixin, FlatRelatedFieldFormMixin, JSONFieldFormMixin
 
@@ -10,8 +13,20 @@ class ImporterModelForm(JSONFieldFormMixin, FlatRelatedFieldFormMixin, CachedCho
     def __init__(self, data, caches, author=None, *args, **kwargs):
         self.caches = caches
         self.author = author
+        self._warnings = defaultdict(list)
         super().__init__(data, *args, **kwargs)
 
+    def add_warning(self, field: str, warning: str):
+        # Mimic django form behaviour for errors
+        if not field:
+            field = NON_FIELD_ERRORS
+
+        self._warnings[field].append(warning)
+
+    @property
+    def warnings(self):
+        return dict(self._warnings)
+
     # This improves preview performance but eliminates validation on uniqueness constraints
     # def validate_unique(self):
     #     pass
